/* File: data_head_key.c; Copyright and License: see below */

#include "entity/data_head_key.h"

/* const char *const DATA_HEAD_KEY_DATA_FILE_FORMAT = "DATA_FILE_FORMAT"; */
const char *const DATA_HEAD_KEY_DATA_FILE_NAME = "DATA_FILE_NAME";
const char *const DATA_HEAD_KEY_DATA_FILE_LAST_SYNC_MOD_TIME = "DATA_FILE_LAST_SYNC_MOD_TIME";


/*
Copyright 2023-2026 Andreas Warnke

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
